"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getJsonPointers = exports.jsonPointerForPosition = exports.getJsonPointerAt = void 0;
const language_1 = require("@codemirror/language");
const constants_1 = require("../constants");
const node_1 = require("./node");
// adapted from https://discuss.codemirror.net/t/json-pointer-at-cursor-seeking-implementation-critique/4793/3
// this could be useful for other things later!
function getJsonPointerAt(docText, node) {
    const path = [];
    for (let n = node; n === null || n === void 0 ? void 0 : n.parent; n = n.parent) {
        switch (n.parent.name) {
            case constants_1.TOKENS.PROPERTY: {
                const name = n.parent.getChild(constants_1.TOKENS.PROPERTY_NAME);
                if (name) {
                    path.unshift((0, node_1.getWord)(docText, name).replace(/[/~]/g, (v) => v === "~" ? "~0" : "~1"));
                }
                break;
            }
            case constants_1.TOKENS.ARRAY: {
                if ((0, node_1.isValueNode)(n)) {
                    const index = (0, node_1.findNodeIndexInArrayNode)(n.parent, n);
                    path.unshift(`${index}`);
                }
                break;
            }
        }
    }
    path.unshift("");
    return path.join("/");
}
exports.getJsonPointerAt = getJsonPointerAt;
/**
 * retrieve a JSON pointer for a given position in the editor
 * @group Utilities
 */
const jsonPointerForPosition = (state, pos, side = -1) => {
    return getJsonPointerAt(state.doc, (0, language_1.syntaxTree)(state).resolve(pos, side));
};
exports.jsonPointerForPosition = jsonPointerForPosition;
/**
 * retrieve a Map of all the json pointers in a document
 * @group Utilities
 */
const getJsonPointers = (state, mode = "json4") => {
    const json = (0, language_1.syntaxTree)(state);
    const pointers = new Map();
    json.iterate({
        enter: (type) => {
            var _a, _b, _c, _d, _e, _f, _g, _h;
            if (type.name === "PropertyName") {
                const pointer = getJsonPointerAt(state.doc, type.node);
                const { from: keyFrom, to: keyTo } = type.node;
                // if there's no value, we can't get the valueFrom/to
                if (!((_b = (_a = type.node) === null || _a === void 0 ? void 0 : _a.nextSibling) === null || _b === void 0 ? void 0 : _b.node)) {
                    pointers.set(pointer, { keyFrom, keyTo });
                    return true;
                }
                const nextNode = mode === "json4"
                    ? (_d = (_c = type.node) === null || _c === void 0 ? void 0 : _c.nextSibling) === null || _d === void 0 ? void 0 : _d.node
                    : (_h = (_g = (_f = (_e = type.node) === null || _e === void 0 ? void 0 : _e.nextSibling) === null || _f === void 0 ? void 0 : _f.node) === null || _g === void 0 ? void 0 : _g.nextSibling) === null || _h === void 0 ? void 0 : _h.node;
                if (!nextNode) {
                    pointers.set(pointer, { keyFrom, keyTo });
                    return true;
                }
                const { from: valueFrom, to: valueTo } = nextNode;
                pointers.set(pointer, { keyFrom, keyTo, valueFrom, valueTo });
                return true;
            }
        },
    });
    return pointers;
};
exports.getJsonPointers = getJsonPointers;
