"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const json_pointer_1 = __importDefault(require("@sagold/json-pointer"));
const json_schema_library_1 = require("json-schema-library");
const step_1 = __importDefault(require("./step"));
const emptyObject = {};
/**
 * Returns the json-schema of a data-json-pointer.
 *
 *  Notes
 *      - Uses draft.step to walk through data and schema
 *
 * @param draft
 * @param pointer - json pointer in data to get the json schema for
 * @param [data] - the data object, which includes the json pointers value. This is optional, as
 *    long as no oneOf, anyOf, etc statement is part of the pointers schema
 * @param [schema] - the json schema to iterate. Defaults to draft.rootSchema
 * @return json schema object of the json-pointer or an error
 */
function getSchema(draft, pointer, data, schema = draft.rootSchema) {
    const frags = json_pointer_1.default.split(pointer);
    schema = draft.resolveRef(schema);
    return _get(draft, schema, frags, pointer, data);
}
exports.default = getSchema;
function _get(draft, schema, frags, pointer, data = emptyObject) {
    if (frags.length === 0) {
        return draft.resolveRef(schema);
    }
    const key = frags.shift(); // step key
    // @ts-expect-error
    schema = (0, step_1.default)(draft, key, schema, data, pointer); // step schema
    if ((0, json_schema_library_1.isJsonError)(schema)) {
        return schema;
    }
    // @ts-expect-error
    data = data[key]; // step data
    return _get(draft, schema, frags, `${pointer}/${key}`, data);
}
