import { syntaxTree } from "@codemirror/language";
var VAL_NODE_NAME = /^(?:Null|True|False|Object|Array|String|Number)$/;
// from https://discuss.codemirror.net/t/json-pointer-at-cursor-seeking-implementation-critique/4793/3
// this could be useful for other things later!
export function getJsonPointerAt(docText, node) {
  var path = [];
  for (var n = node; n && n.parent; n = n.parent) {
    switch (n.parent.name) {
      case "Property": {
        var name_1 = n.parent.getChild("PropertyName");
        if (name_1) {
          path.unshift(
            JSON.parse(docText.sliceString(name_1.from, name_1.to)).replace(
              /[\/~]/g,
              function (v) {
                return v === "~" ? "~0" : "~1";
              }
            )
          );
        }
        break;
      }
      case "Array": {
        if (VAL_NODE_NAME.test(n.name)) {
          var index = 0;
          for (var s = n.prevSibling; s; s = s.prevSibling) {
            if (VAL_NODE_NAME.test(s.name)) {
              index++;
            }
          }
          path.unshift("" + index);
        }
        break;
      }
    }
  }
  path.unshift("");
  return path.join("/");
}
export var jsonPointerForPosition = function (view, pos, side) {
  return getJsonPointerAt(
    view.state.doc,
    syntaxTree(view.state).resolve(pos, side)
  );
};
// retrieve a Map of all the json pointers in a document
export var getJsonPointers = function (view) {
  var json = syntaxTree(view.state);
  var pointers = new Map();
  json.iterate({
    // @ts-expect-error
    enter: function (type) {
      var _a, _b, _c;
      if (type.name === "PropertyName") {
        var pointer = getJsonPointerAt(view.state.doc, type.node);
        var _d = type.node,
          keyFrom = _d.from,
          keyTo = _d.to;
        if (
          !((_a = type.node) === null || _a === void 0
            ? void 0
            : _a.nextSibling)
        ) {
          return { keyFrom: keyFrom, keyTo: keyTo };
        }
        var _e =
            (_c =
              (_b = type.node) === null || _b === void 0
                ? void 0
                : _b.nextSibling) === null || _c === void 0
              ? void 0
              : _c.node,
          valueFrom = _e.from,
          valueTo = _e.to;
        pointers.set(pointer, {
          keyFrom: keyFrom,
          keyTo: keyTo,
          valueFrom: valueFrom,
          valueTo: valueTo,
        });
      }
    },
  });
  return pointers;
};
export function parseJSONDocument(view) {
  var data = null;
  try {
    data = JSON.parse(view.state.doc.toString());
  } catch (_a) {}
  var pointers = getJsonPointers(view);
  return { data: data, pointers: pointers };
}
